aboutsummaryrefslogtreecommitdiff
path: root/src/flash/nor
diff options
context:
space:
mode:
authorSpencer Oliver <ntfreak@users.sourceforge.net>2011-07-28 11:42:27 +0100
committerSpencer Oliver <ntfreak@users.sourceforge.net>2011-07-28 11:42:27 +0100
commitb066a7db2498eadcdeb55ea763d805c75fbbd00b (patch)
treec6207402f2b6001a546ed0baebd19432e4796745 /src/flash/nor
parentb5a324e63c066b97c148c72ecec2e0dfc6023c70 (diff)
downloadriscv-openocd-b066a7db2498eadcdeb55ea763d805c75fbbd00b.zip
riscv-openocd-b066a7db2498eadcdeb55ea763d805c75fbbd00b.tar.gz
riscv-openocd-b066a7db2498eadcdeb55ea763d805c75fbbd00b.tar.bz2
flash: update stm32 driver names
Use consistent names for the stm32 family flash drivers, eg. stm32x -> stm32f1x stm32f2xxx -> stm32f2x this makes it easier to add support for newer stm32 families. Signed-off-by: Spencer Oliver <ntfreak@users.sourceforge.net>
Diffstat (limited to 'src/flash/nor')
-rw-r--r--src/flash/nor/Makefile.am4
-rw-r--r--src/flash/nor/drivers.c8
-rw-r--r--src/flash/nor/stm32f1x.c (renamed from src/flash/nor/stm32x.c)8
-rw-r--r--src/flash/nor/stm32f2x.c (renamed from src/flash/nor/stm32f2xxx.c)21
4 files changed, 20 insertions, 21 deletions
diff --git a/src/flash/nor/Makefile.am b/src/flash/nor/Makefile.am
index c897851..6dd95fe 100644
--- a/src/flash/nor/Makefile.am
+++ b/src/flash/nor/Makefile.am
@@ -24,8 +24,8 @@ NOR_DRIVERS = \
pic32mx.c \
stmsmi.c \
stellaris.c \
- stm32x.c \
- stm32f2xxx.c \
+ stm32f1x.c \
+ stm32f2x.c \
str7x.c \
str9x.c \
str9xpec.c \
diff --git a/src/flash/nor/drivers.c b/src/flash/nor/drivers.c
index dc927b3..669b0b9 100644
--- a/src/flash/nor/drivers.c
+++ b/src/flash/nor/drivers.c
@@ -32,8 +32,8 @@ extern struct flash_driver str9x_flash;
extern struct flash_driver aduc702x_flash;
extern struct flash_driver stellaris_flash;
extern struct flash_driver str9xpec_flash;
-extern struct flash_driver stm32x_flash;
-extern struct flash_driver stm32xf2xxx_flash;
+extern struct flash_driver stm32f1x_flash;
+extern struct flash_driver stm32f2x_flash;
extern struct flash_driver tms470_flash;
extern struct flash_driver ecosflash_flash;
extern struct flash_driver ocl_flash;
@@ -62,8 +62,8 @@ static struct flash_driver *flash_drivers[] = {
&aduc702x_flash,
&stellaris_flash,
&str9xpec_flash,
- &stm32x_flash,
- &stm32xf2xxx_flash,
+ &stm32f1x_flash,
+ &stm32f2x_flash,
&tms470_flash,
&ecosflash_flash,
&ocl_flash,
diff --git a/src/flash/nor/stm32x.c b/src/flash/nor/stm32f1x.c
index b4300be..6bc4300 100644
--- a/src/flash/nor/stm32x.c
+++ b/src/flash/nor/stm32f1x.c
@@ -1544,16 +1544,16 @@ static const struct command_registration stm32x_exec_command_handlers[] = {
static const struct command_registration stm32x_command_handlers[] = {
{
- .name = "stm32x",
+ .name = "stm32f1x",
.mode = COMMAND_ANY,
- .help = "stm32x flash command group",
+ .help = "stm32f1x flash command group",
.chain = stm32x_exec_command_handlers,
},
COMMAND_REGISTRATION_DONE
};
-struct flash_driver stm32x_flash = {
- .name = "stm32x",
+struct flash_driver stm32f1x_flash = {
+ .name = "stm32f1x",
.commands = stm32x_command_handlers,
.flash_bank_command = stm32x_flash_bank_command,
.erase = stm32x_erase,
diff --git a/src/flash/nor/stm32f2xxx.c b/src/flash/nor/stm32f2x.c
index df50e84..c2f586a 100644
--- a/src/flash/nor/stm32f2xxx.c
+++ b/src/flash/nor/stm32f2x.c
@@ -48,8 +48,7 @@
*
*/
-
-/* Danger!!!! The STM32F1xxxx and STM32F2xxxx series actually have
+/* Danger!!!! The STM32F1x and STM32F2x series actually have
* quite different flash controllers.
*
* What's more scary is that the names of the registers and their
@@ -57,7 +56,7 @@
* can be very different.
*
* To reduce testing complexity and dangers of regressions,
- * a seperate file is used for stm32fx2222.
+ * a seperate file is used for stm32fx2x.
*
* 1mByte part with 4 x 16, 1 x 64, 7 x 128kBytes sectors
*
@@ -73,16 +72,16 @@
* PM0059
* www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/PROGRAMMING_MANUAL/CD00233952.pdf
*
* STM32F1xxx series - notice that this code was copy, pasted and knocked
* into a stm32f2xxx driver, so in case something has been converted or
* bugs haven't been fixed, here are the original manuals:
*
* RM0008 - Reference manual
*
* RM0042, the Flash programming manual for low-, medium- high-density and
- * connectivity line STM32F10xxx devices
+ * connectivity line STM32F10x devices
*
- * PM0068, the Flash programming manual for XL-density STM32F10xxx devices.
+ * PM0068, the Flash programming manual for XL-density STM32F10x devices.
*
*/
@@ -683,16 +682,16 @@ static const struct command_registration stm32x_exec_command_handlers[] = {
static const struct command_registration stm32x_command_handlers[] = {
{
- .name = "stm32f2xxx",
+ .name = "stm32f2x",
.mode = COMMAND_ANY,
- .help = "stm32f2xxx flash command group",
+ .help = "stm32f2x flash command group",
.chain = stm32x_exec_command_handlers,
},
COMMAND_REGISTRATION_DONE
};
-struct flash_driver stm32xf2xxx_flash = {
- .name = "stm32f2xxx",
+struct flash_driver stm32f2x_flash = {
+ .name = "stm32f2x",
.commands = stm32x_command_handlers,
.flash_bank_command = stm32x_flash_bank_command,
.erase = stm32x_erase,
@@ -73,16 +72,16 @@
* www.st.com/internet/com/TECHNICAL_RESOURCES/TECHNICAL_LITERATURE/PROGRAMMING_MANUAL/CD00233952.pdf
*
- * STM32F1xxx series - notice that this code was copy, pasted and knocked
- * into a stm32f2xxx driver, so in case something has been converted or
+ * STM32F1x series - notice that this code was copy, pasted and knocked
+ * into a stm32f2x driver, so in case something has been converted or
* bugs haven't been fixed, here are the original manuals:
*